@@ -9,11 +9,11 @@ Test::Valgrind::Command::Perl - A Test::Valgrind command that invokes perl.
 
 =head1 VERSION
 
-Version 1.12
+Version 1.13
 
 =cut
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 =head1 DESCRIPTION
 
@@ -26,7 +26,7 @@ use Env::Sanctify ();
 
 use Test::Valgrind::Suppressions;
 
-use base qw/Test::Valgrind::Command Test::Valgrind::Carp/;
+use base qw<Test::Valgrind::Command Test::Valgrind::Carp>;
 
 =head1 METHODS
 
@@ -224,7 +224,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Vincent Pit, all rights reserved.
+Copyright 2009,2010,2011 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
@@ -270,7 +270,7 @@ my @cards = List::Util::shuffle(0 .. 51);
 {
  package Test::Valgrind::Test::Fake;
 
- use base qw/strict/;
+ use base qw<strict>;
 }
 
-eval 'use Time::HiRes qw/usleep/';
+eval 'use Time::HiRes qw<usleep>';
